import os
from datetime import timedelta
from airflow import DAG
from airflow.operators.bash_operator import BashOperator
from airflow.utils.dates import days_ago
base_path = os.environ["AIRFLOW_HOME"]
default_args = {
    "owner": "airflow",
    "start_date": days_ago(2),
}
# DAG インスタンスをモジュールグローバルに作成
dag = DAG(
    "kuku_workflow",
    default_args=default_args,
    description="九九の計算を行うワークフロー",
    schedule_interval=timedelta(minutes=1),
)
# 小タスクとなるOperatorを記述
task1 = BashOperator(
    task_id="kuku",
    bash_command=f"python {base_path}/src/make_kuku.py -o /tmp/kuku.npy",
    dag=dag,
)
task2 = BashOperator(
    task_id="double",
    depends_on_past=False,
    bash_command=f"python {base_path}/src/calculate_double.py -i /tmp/kuku.npy -o /tmp/double_kuku.npy",
    dag=dag,
)
task3 = BashOperator(
    task_id="sum",
    depends_on_past=False,
    bash_command=f"python {base_path}/src/calculate_sum.py -i /tmp/double_kuku.npy -o /tmp/sum_result.txt",
    dag=dag,
)
# 小タスクの依存関係を記述
task1 >> task2 >> task3
